==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Tux/Resources/translations/Tux_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-TW" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>選擇</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation type="unfinished">Zoom</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>旋轉</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation type="unfinished">Pan</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation type="unfinished">Tilt</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation type="unfinished">Navigation style</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation type="unfinished">Page Up or Page Down key.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation type="unfinished">Rotation focus</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation type="unfinished">Middle mouse button.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation type="unfinished">Navigation style not recognized.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>設定</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>環繞模式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation type="unfinished">Compact</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation type="unfinished">Tooltip</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>可旋轉</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>軌跡球</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>未定義</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or H key.</source>
      <translation type="unfinished">Middle mouse button or H key.</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Tux/Resources/translations/Tux_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="NavigationIndicatorGui.py" line="63"/>
      <source>Select</source>
      <translation>選擇</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="64"/>
      <source>Zoom</source>
      <translation type="unfinished">Zoom</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="65"/>
      <source>Rotate</source>
      <translation>旋轉</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="66"/>
      <source>Pan</source>
      <translation type="unfinished">Pan</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="67"/>
      <source>Tilt</source>
      <translation type="unfinished">Tilt</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="68"/>
      <source>Navigation style</source>
      <translation type="unfinished">Navigation style</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="69"/>
      <source>Page Up or Page Down key.</source>
      <translation type="unfinished">Page Up or Page Down key.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="70"/>
      <source>Rotation focus</source>
      <translation type="unfinished">Rotation focus</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="73"/>
      <source>Middle mouse button.</source>
      <translation type="unfinished">Middle mouse button.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="76"/>
      <source>Navigation style not recognized.</source>
      <translation type="unfinished">Navigation style not recognized.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>設定</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>環繞模式</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation type="unfinished">Compact</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation type="unfinished">Tooltip</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>可旋轉</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>軌跡球</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>未定義</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button or H key.</source>
      <translation type="unfinished">Middle mouse button or H key.</translation>
    </message>
  </context>
</TS>
